OC.L10N.register(
    "settings",
    {
    "Private" : "Prywatne",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Widoczne tylko dla osób dopasowanych poprzez integrację numeru telefonu za pomocą Talka na telefonie komórkowym",
    "Local" : "Lokalne",
    "Only visible to people on this instance and guests" : "Widoczne tylko dla osób w tej instancji i gości",
    "Federated" : "Sfederowane",
    "Only synchronize to trusted servers" : "Synchronizuj tylko z zaufanymi serwerami",
    "Published" : "Opublikowane",
    "Synchronize to trusted servers and the global and public address book" : "Synchronizuj z zaufanymi serwerami oraz globalną i publiczną książką adresową",
    "Verify" : "Zweryfikuj",
    "Verifying …" : "Weryfikacja…",
    "Unable to change password" : "Nie można zmienić hasła",
    "Very weak password" : "Bardzo słabe hasło",
    "Weak password" : "Słabe hasło",
    "So-so password" : "Mało skomplikowane hasło",
    "Good password" : "Dobre hasło",
    "Strong password" : "Mocne hasło",
    "Groups" : "Grupy",
    "Group list is empty" : "Lista grup jest pusta",
    "Unable to retrieve the group list" : "Nie można pobrać listy grup",
    "{actor} added you to group {group}" : "{actor} dodał Ciebie do grupy {group}",
    "You added {user} to group {group}" : "Dodałeś {user} do grupy {group}",
    "{actor} added {user} to group {group}" : "{actor} dodał {user} do grupy {group}",
    "An administrator added you to group {group}" : "Administrator dodał Ciebie do grupy {group}",
    "An administrator added {user} to group {group}" : "Administrator dodał {user} do grupy {group}",
    "{actor} removed you from group {group}" : "{actor} usunął Ciebie z grupy {group}",
    "You removed {user} from group {group}" : "Usunąłeś {user} z grupy {group}",
    "{actor} removed {user} from group {group}" : "{actor} usunął {user} z grupy {group}",
    "An administrator removed you from group {group}" : "Administrator usunął Ciebie z grupy {group}",
    "An administrator removed {user} from group {group}" : "Administrator usunął {user} z grupy {group}",
    "Your <strong>group memberships</strong> were modified" : "Twoja <strong>przynależność do grupy</strong> została zmodyfikowana",
    "{actor} changed your password" : "{actor} zmienił Twoje hasło",
    "You changed your password" : "Zmieniłeś swoje hasło",
    "Your password was reset by an administrator" : "Twoje hasło zostało zresetowane przez administratora",
    "Your password was reset" : "Twoje hasło zostało zresetowane",
    "{actor} changed your email address" : "{actor} zmienił Twój adres e-mail",
    "You changed your email address" : "Zmieniłeś swój adres e-mail",
    "Your email address was changed by an administrator" : "Twój adres e-mail został zmieniony przez administratora",
    "You created app password \"{token}\"" : "Utworzono hasło aplikacji \"{token}\"",
    "An administrator created app password \"{token}\"" : "Hasło aplikacji \"{token}\" zostało utworzone przez administratora",
    "You deleted app password \"{token}\"" : "Usunięto hasło aplikacji \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Zmieniłeś hasło aplikacji \"{token}\" na \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Udzieliłeś dostępu do systemu plików dla hasła aplikacji \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Cofnąłeś dostęp do systemu plików dla hasła aplikacji \"{token}\"",
    "Security" : "Bezpieczeństwo",
    "You successfully logged in using two-factor authentication (%1$s)" : "Pomyślnie zalogowano się za pomocą uwierzytelniania dwuskładnikowego (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Próba logowania przy użyciu uwierzytelniania dwuskładnikowego nie powiodła się (%1$s)",
    "Remote wipe was started on %1$s" : "Zdalne czyszczenie zostało uruchomione w %1$s",
    "Remote wipe has finished on %1$s" : "Zdalne czyszczenie zakończyło się w %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Twoje <strong>hasło</strong> lub <strong>e-mail</strong> został zmieniony",
    "Could not remove app." : "Usuwanie aplikacji nie powiodło się.",
    "Could not update app." : "Nie można uaktualnić aplikacji.",
    "Wrong password" : "Złe hasło",
    "Unable to change personal password" : "Nie można zmienić osobistego hasła",
    "Saved" : "Zapisano",
    "No user supplied" : "Brak użytkownika",
    "Unable to change password. Password too long." : "Nie można zmienić hasła. Hasło jest za długie.",
    "Authentication error" : "Błąd uwierzytelniania",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Podaj hasło odzyskiwania administratora; w przeciwnym razie wszystkie dane użytkownika zostaną utracone.",
    "Wrong admin recovery password. Please check the password and try again." : "Błędne hasło odzyskiwania administratora. Sprawdź hasło i spróbuj ponownie.",
    "Backend does not support password change, but the user's encryption key was updated." : "System zaplecza nie obsługuje zmiany hasła, ale klucz szyfrowania użytkownika został zaktualizowany.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instalowanie i aktualizowanie aplikacji za pośrednictwem sklepu z aplikacjami lub Udostępnionej Chmury Federacyjnej",
    "Federated Cloud Sharing" : "Udostępnianie Chmury Federacyjnej",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL używa nieaktualnej %1$s wersji (%2$s). Zaktualizuj system operacyjny lub funkcje takie jak %3$s nie będą działać prawidłowo.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Nie można określić, czy wersja TLS cURL jest aktualna, ponieważ wystąpił błąd podczas żądania HTTPS skierowanego do https://nextcloud.com. Aby uzyskać więcej informacji, sprawdź plik dziennika Nextcloud.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Moduł PHP OPcache nie jest wczytany. Aby uzyskać lepszą wydajność, zaleca się wczytanie go do instalacji PHP.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache jest wyłączone. Aby uzyskać lepszą wydajność, zaleca się zastosowanie <code>opcache.enable=1</code> w konfiguracji PHP.",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache jest skonfigurowane do usuwania komentarzy kodu. Przy włączonym OPcache, musi być ustawione <code>opcache.save_comments=1</code>, aby działał Nextcloud.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud nie może korzystać z interfejsu OPcache API. Po włączeniu OPcache zdecydowanie zaleca się uwzględnienie wszystkich katalogów Nextcloud z <code>opcache.restrict_api</code> lub usunięcie tego ustawienia, aby wyłączyć ograniczenia interfejsu OPcache API, żeby zapobiec błędom podczas aktualizacji rdzenia lub aplikacji Nextcloud.",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud nie może korzystać z interfejsu OPcache API. Zdecydowanie zaleca się uwzględnienie wszystkich katalogów Nextcloud z <code>opcache.restrict_api</code> lub usunięcie tego ustawienia, aby wyłączyć ograniczenia interfejsu OPcache API, żeby zapobiec błędom podczas aktualizacji rdzenia lub aplikacji Nextcloud.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Maksymalna liczba kluczy OPcache jest prawie przekroczona. Aby mieć pewność, że wszystkie skrypty mogą być przechowywane w pamięci podręcznej, zaleca się zastosowanie <code>opcache.max_accelerated_files</code> w konfiguracji PHP z wartością wyższą niż <code>%s</code>.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "Bufor OPcache jest prawie pełny. Aby upewnić się, że wszystkie skrypty mogą być przechowywane w pamięci podręcznej, zaleca się zastosowanie <code>opcache.memory_consumption</code> w konfiguracji PHP z wartością wyższą niż <code>%s</code>.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "Bufor ciągów internowanych OPcache jest prawie pełny. Aby upewnić się, że powtarzające się ciągi mogą być efektywnie buforowane, zaleca się zastosowanie <code>opcache.interned_strings_buffer</code> w konfiguracji PHP z wartością wyższą niż <code>%s</code>.",
    "Invalid SMTP password." : "Nieprawidłowe hasło SMTP.",
    "Email setting test" : "Test ustawień e-mail",
    "Well done, %s!" : "Dobra robota, %s!",
    "If you received this email, the email configuration seems to be correct." : "Jeśli otrzymałeś tego e-maila, to wydaje się, że konfiguracja e-maila jest prawidłowa.",
    "Email could not be sent. Check your mail server log" : "E-mail nie został wysłany. Sprawdź logi swojego serwera poczty",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Wystąpił problem podczas wysyłania wiadomości e-mail. Zmień ustawienia. (Błąd: %s)",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Musisz ustawić swój adres e-mail użytkownika, zanim będziesz mógł wysyłać e-maile testowe. Przejdź do %s.",
    "Invalid user" : "Nieprawidłowy użytkownik",
    "Invalid mail address" : "Nieprawidłowy adres e-mail",
    "Settings saved" : "Zapisano ustawienia",
    "Unable to change full name" : "Nie można zmienić pełnej nazwy",
    "Unable to change email address" : "Nie można zmienić adresu e-mail",
    "Unable to set invalid phone number" : "Nie można ustawić nieprawidłowego numeru telefonu",
    "Unable to set invalid website" : "Nie można ustawić nieprawidłowej strony internetowej",
    "Some account data was invalid" : "Niektóre dane konta są nieprawidłowe",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Aby zweryfikować swoje konto Twittera, wyślij poniższego tweeta (upewnij się, że cały tekst zawiera się w jednej linii):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Aby zweryfikować swoją stronę umieść poniższą zawartość w katalogu głównym serwera pod adresem '.well-known/CloudIdVerificationCode.txt' (upewnij się, że cały tekst zawiera się w jednej linii):",
    "%1$s changed your password on %2$s." : "%1$s zmienił Twoje hasło w %2$s.",
    "Your password on %s was changed." : "Twoje hasło w %s zostało zmienione.",
    "Your password on %s was reset by an administrator." : "Twoje hasło w %s zostało zresetowane przez administratora",
    "Your password on %s was reset." : "Twoje hasło w %s zostało zresetowane.",
    "Password for %1$s changed on %2$s" : "Hasło dla %1$s zostało zmienione w %2$s",
    "Password changed for %s" : "Hasło zostało zmienione dla %s",
    "If you did not request this, please contact an administrator." : "Jeśli nie żądałeś tego, skontaktuj się z administratorem.",
    "Your email address on %s was changed." : "Twój adres e-mail w %s został zmieniony.",
    "Your email address on %s was changed by an administrator." : "Twój adres e-mail w %s został zmieniony przez administratora.",
    "Email address for %1$s changed on %2$s" : "Adres e-mail dla %1$s został zmieniony w %2$s",
    "Email address changed for %s" : "Został zmieniony adres e-mail dla %s",
    "The new email address is %s" : "Nowy adres e-mail to %s",
    "Your %s account was created" : "Twoje konto %s zostało utworzone",
    "Welcome aboard" : "Witamy na pokładzie",
    "Welcome aboard %s" : "Witamy na pokładzie %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Witamy na koncie %s, możesz dodawać, chronić i udostępniać swoje dane.",
    "Your username is: %s" : "Twoja nazwa użytkownika to: %s",
    "Set your password" : "Ustaw hasło",
    "Go to %s" : "Przejdź do %s",
    "Install Client" : "Zainstaluj klienta",
    "Logged in user must be a subadmin" : "Zalogowany użytkownik musi być współadminem",
    "Apps" : "Aplikacje",
    "Settings" : "Ustawienia",
    "Personal" : "Osobiste",
    "Administration" : "Administracja",
    "Additional settings" : "Ustawienia dodatkowe",
    "Administration privileges" : "Uprawnienia administracyjne",
    "Groupware" : "Praca grupowa",
    "Overview" : "Przegląd",
    "Basic settings" : "Ustawienia podstawowe",
    "Sharing" : "Udostępnianie",
    "Availability" : "Dostępność",
    "Personal info" : "Informacje osobiste",
    "Mobile & desktop" : "Mobilne i stacjonarne",
    "Email server" : "Serwer poczty",
    "Security & setup warnings" : "Ostrzeżenia bezpieczeństwa i konfiguracji",
    "Background jobs" : "Zadania w tle",
    "Create" : "Utwórz",
    "Change" : "Zmień",
    "Delete" : "Usuń",
    "Reshare" : "Udostępnianie innym",
    "Unlimited" : "Bez limitu",
    "Verifying" : "Sprawdzanie",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Oczekiwanie zadania w tle, które sprawdza certyfikaty SSL zaimportowane przez użytkownika. Sprawdź później.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Istnieją pewne certyfikaty SSL zaimportowane przez użytkownika, które nie są już używane z Nextcloud 21. Można je zaimportować z wiersza poleceń za pomocą polecenia \"occ security:certificates:import\". Ich ścieżki w katalogu danych są pokazane poniżej.",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Znaleziono nieprawidłowe identyfikatory UUID użytkowników lub grup LDAP. Sprawdź ustawienia \"Zastąp wykrywanie UUID\" w części eksperckiej konfiguracji LDAP i użyj \"occ ldap:update-uuid\", aby je zaktualizować.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Stary format szyfrowania po stronie serwera jest włączony. Zalecamy wyłączenie jego.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Używana jest wersja MariaDB \"%s\". Nextcloud 21 i nowsze wersje nie obsługują tej wersji i wymagają MariaDB 10.2 lub nowszej.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Używana jest wersja MySQL \"%s\". Nextcloud 21 i nowsze wersje nie obsługują tej wersji i wymagają MySQL 8.0 lub MariaDB 10.2, albo nowszej.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Używana jest wersja PostgreSQL \"%s\". Nextcloud 21 i nowsze wersje nie obsługują tej wersji i wymagają PostgreSQL 9.6 lub nowszej.",
    "Profile information" : "Informacje o profilu",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Zdjęcie profilowe, imię i nazwisko, adres e-mail, numer telefonu, adres, witryna internetowa, Twitter, organizacja, rola, nagłówek, biografia i czy Twój profil jest włączony",
    "Nextcloud settings" : "Ustawienia Nextcloud",
    "Here you can decide which group can access certain sections of the administration settings." : "Możesz zdecydować, która grupa ma dostęp do określonych sekcji ustawień administracyjnych.",
    "None" : "Brak",
    "Unable to modify setting" : "Nie można zmienić ustawienia",
    "Two-Factor Authentication" : "Uwierzytelnianie dwuskładnikowe",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Uwierzytelnianie dwuskładnikowe może być wymuszane dla wszystkich użytkowników i określonych grup. Jeśli nie mają skonfigurowanego dostawcy logowania dwuskładnikowego, nie będą mogli zalogować się do systemu.",
    "Enforce two-factor authentication" : "Wymuś uwierzytelnianie dwuskładnikowe",
    "Limit to groups" : "Ogranicz do grup",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Wymuszanie uwierzytelniania dwuskładnikowego można ustawić tylko dla niektórych grup.",
    "Two-factor authentication is enforced for all members of the following groups." : "Uwierzytelnianie dwuskładnikowe jest wymuszone dla wszystkich członków następujących grup.",
    "Enforced groups" : "Wymuszone grupy",
    "Two-factor authentication is not enforced for members of the following groups." : "Uwierzytelnianie dwuskładnikowe nie jest wymuszane dla członków następujących grup.",
    "Excluded groups" : "Wyłączone grupy",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Gdy grupy są wybierane/wykluczane, używają następującej logiki do określenia, czy użytkownik ma wymuszone 2FA: Jeśli nie wybrano żadnych grup, 2FA jest włączone dla wszystkich, z wyjątkiem członków grup wykluczonych. Jeśli wybrane są grupy, opcja 2FA jest włączona dla wszystkich członków. Jeśli użytkownik znajduje się zarówno w grupie wybranej, jak i wykluczonej, wybrane ma pierwszeństwo, a 2FA jest wymuszone.",
    "Save changes" : "Zapisz zmiany",
    "All" : "Wszystkie",
    "Limit app usage to groups" : "Ogranicz korzystanie z aplikacji dla grup",
    "No results" : "Brak wyników",
    "Update to {version}" : "Zaktualizuj do {version}",
    "Remove" : "Usuń",
    "Disable" : "Wyłącz",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ta aplikacja nie ma przypisanej minimalnej wersji Nextcloud. W przyszłości będzie to błąd.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ta aplikacja nie ma przypisanej maksymalnej wersji Nextcloud. W przyszłości będzie to błąd.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ta aplikacja nie może być zainstalowana, ponieważ nie są spełnione następujące zależności:",
    "View in store" : "Zobacz w sklepie",
    "Visit website" : "Odwiedź stronę",
    "Report a bug" : "Zgłoś błąd",
    "User documentation" : "Dokumentacja użytkownika",
    "Admin documentation" : "Dokumentacja administratora",
    "Developer documentation" : "Dokumentacja dewelopera",
    "This app is supported via your current Nextcloud subscription." : "Ta aplikacja jest obsługiwana za pośrednictwem bieżącej subskrypcji Nextcloud.",
    "Supported" : "Wspierany",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Polecane aplikacje są tworzone przez społeczność. Oferują główną funkcjonalność i są gotowe do użycia w produkcji.",
    "Featured" : "Polecane",
    "Update to {update}" : "Zaktualizuj do {update}",
    "All apps are up-to-date." : "Wszystkie aplikacje są aktualne.",
    "Results from other categories" : "Wyniki z innych kategorii",
    "No apps found for your version" : "Nie znaleziono aplikacji dla Twojej wersji",
    "Disable all" : "Wyłącz wszystkie",
    "Enable all" : "Włącz wszystkie",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n aplikacja ma dostępną aktualizację","%n aplikacje mają dostępną aktualizację","%n aplikacji mają dostępną aktualizację","%n aplikacji mają dostępną aktualizację"],
    "_Update_::_Update all_" : ["Zaktualizuj","Zaktualizuj","Zaktualizuj","Zaktualizuj wszystko"],
    "Marked for remote wipe" : "Oznaczone do zdalnego czyszczenia",
    "Device settings" : "Ustawienia urządzenia",
    "Allow filesystem access" : "Zezwalaj na dostęp do systemu plików",
    "Rename" : "Zmień nazwę",
    "Revoke" : "Cofnij",
    "Wipe device" : "Wyczyść urządzenie",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Unieważnienie tego tokena uniemożliwi czyszczenie urządzenia, jeśli jeszcze nie zostało rozpoczęte.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome dla Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "Aplikacja {productName} na iOS",
    "{productName} Android app" : "Aplikacja {productName} na Android",
    "{productName} Talk for iOS" : "{productName} Talk dla iOS",
    "{productName} Talk for Android" : "{productName} Talk dla Androida",
    "Sync client - {os}" : "Klient synchronizacji - {os}",
    "This session" : "Ta sesja",
    "Device" : "Urządzenie",
    "Last activity" : "Ostatnia aktywność",
    "Devices & sessions" : "Urządzenia i sesje",
    "Web, desktop and mobile clients currently logged in to your account." : "Klienci internetowi, desktopowi i mobilni aktualnie zalogowani na Twoim koncie.",
    "Do you really want to wipe your data from this device?" : "Czy na pewno chcesz usunąć dane z tego urządzenia?",
    "Confirm wipe" : "Potwierdzenie usunięcia",
    "Error while creating device token" : "Błąd podczas tworzenia tokena urządzenia",
    "Error while updating device token scope" : "Błąd podczas aktualizacji zakresu tokena urządzenia",
    "Error while updating device token name" : "Błąd podczas aktualizacji nazwy tokena urządzenia",
    "Error while deleting the token" : "Błąd podczas usuwania tokena",
    "Error while wiping the device with the token" : "Błąd podczas czyszczenia urządzenia za pomocą tokena",
    "App name" : "Nazwa aplikacji",
    "Create new app password" : "Utwórz nowe hasło aplikacji",
    "Use the credentials below to configure your app or device." : "Użyj poniższych poświadczeń, aby skonfigurować aplikację lub urządzenie.",
    "For security reasons this password will only be shown once." : "Ze względów bezpieczeństwa hasło zostanie pokazane tylko raz.",
    "Username" : "Nazwa użytkownika",
    "Password" : "Hasło",
    "Done" : "Gotowe",
    "Show QR code for mobile apps" : "Pokaż kod QR dla aplikacji mobilnych",
    "Copied!" : "Skopiowano!",
    "Copy" : "Kopiuj",
    "Could not copy app password. Please copy it manually." : "Nie można skopiować hasła do aplikacji. Skopiuj je ręcznie.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Dla prawidłowego działania serwera, ważne jest, aby poprawnie skonfigurować zadania w tle. Zalecanym ustawieniem jest Cron. Więcej informacji znajdziesz w dokumentacji.",
    "Last job execution ran {time}. Something seems wrong." : "Wykonanie ostatniego zadania trwało {time}. Coś wydaje się nie tak.",
    "Last job ran {relativeTime}." : "Ostatnie zadanie zostało uruchomione {relativeTime}.",
    "Background job did not run yet!" : "Zadanie w tle nie zostało wykonane ani razu!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "Wykonaj jedno zadanie z każdą załadowaną stroną. Przypadek użycia: Wystąpienie pojedynczego użytkownika.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php jest zarejestrowany w usłudze webcron i wywołuje cron.php co 5 minut przez HTTP. Przypadek użycia: Bardzo mała instancja (1–5 użytkowników w zależności od zastosowania).",
    "Cron (Recommended)" : "Cron (zalecane)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Dla uruchomienia tego potrzebujesz rozszerzenia PHP POSIX. Zobacz {linkstart}dokumentację PHP{linkend}, aby uzyskać więcej szczegółów.",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Użyj usługi systemowej crona, aby co 5 minut wywoływać plik cron.php. Zalecane dla wszystkich instancji.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "Plik cron.php musi zostać wykonany przez użytkownika systemowego \"{user}\".",
    "Unable to update background job mode" : "Nie można zaktualizować trybu zadania w tle",
    "Profile" : "Profil",
    "Enable or disable profile by default for new users." : "Domyślnie włączanie lub wyłączanie profilu dla nowych użytkowników.",
    "Enable" : "Włącz",
    "Unable to update profile default setting" : "Nie można zaktualizować domyślnych ustawień profilu",
    "Server-side encryption" : "Szyfrowanie po stronie serwera",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Szyfrowanie po stronie serwera umożliwia szyfrowanie plików przesyłanych na ten serwer. Wiąże się to z ograniczeniami, takimi jak spadkiem wydajności, więc włącz to tylko w razie potrzeby.",
    "Enable server-side encryption" : "Włącz szyfrowanie po stronie serwera",
    "Please read carefully before activating server-side encryption:" : "Przeczytaj uważnie przed aktywacją szyfrowania po stronie serwera:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Po włączeniu szyfrowania wszystkie pliki wysłane na serwer od tej chwili będą szyfrowane na serwerze. Wyłączenie szyfrowania będzie możliwe dopiero, gdy aktywny moduł szyfrowania wykona tę funkcję oraz wszystkie poprzednie warunki będą spełnione (np. ustawienie klucza odzyskiwania).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Samo szyfrowanie nie gwarantuje bezpieczeństwa systemu. Więcej informacji na temat działania aplikacji szyfrującej i użycia wspieranych przypadków można znaleźć w dokumentacji.",
    "Be aware that encryption always increases the file size." : "Należy pamiętać, że szyfrowanie zawsze zwiększa rozmiar pliku.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Zawsze dobrze jest regularnie wykonywać kopie zapasowe swoich danych. W przypadku szyfrowania upewnij się, aby kopie zapasowe kluczy szyfrowania były wraz z danymi.",
    "This is the final warning: Do you really want to enable encryption?" : "To ostatnie ostrzeżenie: Czy na pewno chcesz włączyć szyfrowanie?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Moduł szyfrowania nie jest załadowany, należy włączyć moduł szyfrowania w menu aplikacji.",
    "Select default encryption module:" : "Wybierz domyślny moduł szyfrowania:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Musisz zmigrować swoje klucze szyfrujące ze starego szyfrowania (ownCloud <= 8.0) do nowego. Włącz \"Domyślny moduł szyfrowania\" i uruchom {command}",
    "Unable to update server side encryption config" : "Nie można zaktualizować konfiguracji szyfrowania po stronie serwera",
    "Rename group" : "Zmień nazwę grupy",
    "Remove group" : "Usuń grupę",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Zamierzasz usunąć grupę {group}. Użytkownicy NIE zostaną usunięci.",
    "Please confirm the group removal " : "Potwierdź usunięcie grupy",
    "Current password" : "Bieżące hasło",
    "New password" : "Nowe hasło",
    "Change password" : "Zmień hasło",
    "Your profile picture" : "Twoje zdjęcie profilowe",
    "Upload profile picture" : "Wyślij zdjęcie profilowe",
    "Choose profile picture from files" : "Wybierz zdjęcie profilowe z Plików",
    "Remove profile picture" : "Usuń zdjęcie profilowe",
    "png or jpg, max. 20 MB" : "png lub jpg, maks. 20 MB",
    "Picture provided by original account" : "Zdjęcie dostarczone przez oryginalne konto",
    "Cancel" : "Anuluj",
    "Set as profile picture" : "Ustaw jako zdjęcie profilowe",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Pamiętaj, że aktualizacja Twojego zdjęcia profilowego może potrwać do 24 godzin.",
    "Choose your profile picture" : "Wybierz swoje zdjęcie profilowe",
    "Please select a valid png or jpg file" : "Wybierz prawidłowy plik png lub jpg",
    "Error setting profile picture" : "Błąd podczas ustawiania zdjęcia profilowego",
    "Error cropping profile picture" : "Błąd przycinania zdjęcia profilowego",
    "Error saving profile picture" : "Błąd podczas zapisywania zdjęcia profilowego",
    "Error removing profile picture" : "Błąd podczas usuwania zdjęcia profilowego",
    "Your biography" : "Twoja biografia",
    "Details" : "Szczegóły",
    "You are a member of the following groups:" : "Należysz do następujących grup:",
    "You are using <strong>{usage}</strong>" : "Używasz <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Używasz <strong>{usage}</strong> z <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Your full name" : "Twoja pełna nazwa",
    "Email options" : "Opcje e-mail",
    "Primary email for password reset and notifications" : "Główny adres e-mail do resetowania hasła i powiadomień",
    "Remove primary email" : "Usuń podstawowy adres e-mail",
    "Delete email" : "Usuń e-mail",
    "Unset as primary email" : "Usuń jako podstawowy adres e-mail",
    "This address is not confirmed" : "Ten adres nie jest potwierdzony",
    "Set as primary email" : "Ustaw jako podstawowy adres e-mail",
    "Your email address" : "Twój adres e-mail",
    "Additional email address {index}" : "Dodatkowy adres e-mail {index}",
    "Unable to delete primary email address" : "Nie można usunąć głównego adresu e-mail",
    "Unable to update primary email address" : "Nie można zaktualizować głównego adresu e-mail",
    "Unable to add additional email address" : "Nie można dodać dodatkowego adresu e-mail",
    "Unable to update additional email address" : "Nie można zaktualizować dodatkowego adresu e-mail",
    "Unable to delete additional email address" : "Nie można usunąć dodatkowego adresu e-mail",
    "No email address set" : "Brak adresu e-mail",
    "Additional emails" : "Dodatkowe e-maile",
    "Your headline" : "Twój nagłówek",
    "Language" : "Język",
    "Help translate" : "Pomóż w tłumaczeniu",
    "Unable to update language" : "Nie można zaktualizować języka",
    "No language set" : "Nie ustawiono języka",
    "Locale" : "Region",
    "Week starts on {firstDayOfWeek}" : "Tydzień zaczyna się w {firstDayOfWeek}",
    "Unable to update locale" : "Nie można zaktualizować regionu",
    "No locale set" : "Nie ustawiono regionu",
    "Your location" : "Twoja lokalizacja",
    "Your organisation" : "Twoja organizacja",
    "Your phone number" : "Twój numer telefonu",
    "Edit your Profile visibility" : "Edycja widoczności swojego profilu",
    "Enable Profile" : "Włącz profil",
    "Unable to update profile enabled state" : "Nie można zaktualizować stanu włączenia profilu",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Bardziej restrykcyjne ustawienie widoczności lub zakresu jest przestrzegane w Twoim profilu. Na przykład, jeśli widoczność jest ustawiona na \"Pokaż wszystkim\", a zakres jest ustawiony na \"Prywatny\", to przestrzegany jest \"Prywatny\".",
    "{displayId}" : "{displayId}",
    "Unable to update visibility of {displayId}" : "Nie można zaktualizować widoczności {displayId}",
    "Your role" : "Twoja rola społeczna",
    "Your Twitter handle" : "Twój Twitter:",
    "Your website" : "Twoja strona WWW",
    "No {property} set" : "Nie ustawiono {property}",
    "Unable to update {property}" : "Nie można zaktualizować {property}",
    "Change scope level of {property}, current scope is {scope}" : "Zmień poziom zakresu {property}, obecny zakres to {scope}",
    "Unable to update federation scope of the primary {property}" : "Nie można zaktualizować zakresu federacji podstawowej {property}",
    "Unable to update federation scope of additional {property}" : "Nie można zaktualizować zakresu federacji dodatkowego {property}",
    "Add additional email" : "Dodaj dodatkowy e-mail",
    "Add" : "Dodaj",
    "You do not have permissions to see the details of this user" : "Nie masz uprawnień aby zobaczyć informacje o tym użytkowniku",
    "Add new password" : "Dodaj nowe hasło",
    "Add new email address" : "Dodaj nowy adres e-mail",
    "Add user to group" : "Dodaj użytkownika do grupy",
    "Set user as admin for" : "Ustaw administratora dla",
    "Select user quota" : "Wybierz limit dla użytkownika",
    "Delete user" : "Usuń użytkownika",
    "Wipe all devices" : "Wyczyść wszystkie urządzenia",
    "Disable user" : "Zablokuj użytkownika",
    "Enable user" : "Odblokuj użytkownika",
    "Resend welcome email" : "Wyślij ponownie wiadomość powitalną",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "W przypadku zagubienia urządzenia lub opuszczenia organizacji można zdalnie wyczyścić dane Nextcloud ze wszystkich urządzeń powiązanych z {userid}. Działa tylko wtedy, gdy urządzenia są podłączone do Internetu.",
    "Remote wipe of devices" : "Zdalne czyszczenie urządzeń",
    "Wipe {userid}'s devices" : "Wyczyść urządzenia {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Całkowicie usuń konto {userid}, w tym wszystkie pliki osobiste, dane aplikacji itp.",
    "Account deletion" : "Usunięcie konta",
    "Delete {userid}'s account" : "Usuń konto {userid}",
    "Welcome mail sent!" : "Wysłano wiadomość powitalną!",
    "Edit User" : "Edytuj użytkownika",
    "Toggle user actions menu" : "Przełącz menu czynności użytkownika",
    "{size} used" : "Wykorzystane: {size}",
    "New user" : "Nowy użytkownik",
    "Will be autogenerated" : "Zostanie automatycznie wygenerowany",
    "Display name" : "Nazwa wyświetlana",
    "Email" : "E-mail",
    "Default language" : "Domyślny język",
    "Add a new user" : "Dodaj użytkownika",
    "Group admin for" : "Administrator grupy",
    "Quota" : "Limit",
    "User backend" : "Moduł użytkownika",
    "Storage location" : "Lokalizacja magazynu",
    "Last login" : "Ostatnio zalogowany",
    "No users in here" : "Brak użytkowników",
    "Default quota" : "Domyślny limit",
    "Common languages" : "Popularne języki",
    "Other languages" : "Inne języki",
    "Password change is disabled because the master key is disabled" : "Zmiana hasła jest zablokowana z powodu włączenia klucza głównego.",
    "Passwordless authentication requires a secure connection." : "Uwierzytelnianie bez hasła wymaga bezpiecznego połączenia.",
    "Add WebAuthn device" : "Dodaj urządzenie WebAuthn",
    "Please authorize your WebAuthn device." : "Autoryzuj swoje urządzenie WebAuthn.",
    "Name your device" : "Nazwa twojego urządzenia",
    "Adding your device …" : "Dodawanie urządzenia…",
    "Server error while trying to add WebAuthn device" : "Błąd serwera podczas próby dodania urządzenia WebAuthn",
    "Server error while trying to complete WebAuthn device registration" : "Błąd serwera podczas próby ukończenia rejestracji urządzenia WebAuthn",
    "Unnamed device" : "Nienazwane urządzenie",
    "Passwordless Authentication" : "Uwierzytelnianie bez hasła",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Skonfiguruj konto do uwierzytelniania bez hasła zgodnie ze standardem FIDO2.",
    "No devices configured." : "Brak skonfigurowanych urządzeń.",
    "The following devices are configured for your account:" : "Dla Twojego konta skonfigurowane są następujące urządzenia:",
    "Your browser does not support WebAuthn." : "Twoja przeglądarka nie obsługuje WebAuthn.",
    "Your apps" : "Twoje aplikacje",
    "Active apps" : "Aktywne aplikacje",
    "Disabled apps" : "Wyłączone aplikacje",
    "Updates" : "Aktualizacje",
    "App bundles" : "Zestawy aplikacji",
    "Featured apps" : "Polecane aplikacje",
    "{license}-licensed" : "na licencji {license}",
    "Changelog" : "Dziennik zmian",
    "by {author}\n{license}" : "wykonane przez {author}\n{license}",
    "Enter group name" : "Wpisz nazwę grupy",
    "Add group" : "Dodaj grupę",
    "Active users" : "Aktywni użytkownicy",
    "Admins" : "Administratorzy",
    "Disabled users" : "Zablokowani użytkownicy",
    "Default quota:" : "Domyślny limit:",
    "Select default quota" : "Wybierz domyślny limit",
    "Show Languages" : "Pokaż języki",
    "Show last login" : "Pokaż ostatnie logowanie",
    "Show user backend" : "Pokaż moduł użytkownika",
    "Show storage path" : "Pokaż ścieżkę przechowywania",
    "Send email to new user" : "Wyślij e-mail do nowego użytkownika",
    "Not saved" : "Nie zapisano",
    "Sending…" : "Wysyłam…",
    "Email sent" : "E-mail został wysłany",
    "Location" : "Lokalizacja",
    "Profile picture" : "Zdjęcie profilowe",
    "About" : "Informacje",
    "Full name" : "Pełna nazwa",
    "Additional email" : "Dodatkowy e-mail",
    "Headline" : "Nagłówek",
    "Organisation" : "Organizacja",
    "Phone number" : "Numer telefonu",
    "Role" : "Rola społeczna",
    "Twitter" : "Twitter",
    "Website" : "Strona internetowa",
    "Profile visibility" : "Widoczność profilu",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Niedostępne, ponieważ ta właściwość jest wymagana do podstawowych funkcji, w tym udostępniania pliku i zaproszeń do kalendarza",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Niedostępne, ponieważ federacja została wyłączona na Twoim koncie, skontaktuj się z administratorem systemu, jeśli masz jakieś pytania",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Niedostępne, ponieważ publikowanie danych specyficznych dla użytkownika na serwerze wyszukiwania jest niedozwolone, skontaktuj się z administratorem systemu, jeśli masz jakiekolwiek pytania",
    "Show to everyone" : "Pokaż wszystkim",
    "Show to logged in users only" : "Pokaż tylko zalogowanym użytkownikom",
    "Hide" : "Ukryj",
    "Download and enable" : "Pobierz i włącz",
    "Enable untested app" : "Włącz nietestowaną aplikację",
    "The app will be downloaded from the App Store" : "Aplikacja zostanie pobrana ze sklepu z aplikacjami",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ta aplikacja jest niezgodna z wersją Nextcloud. Przy dalszej kontynuacji, możesz pozwolić na zainstalowanie tej aplikacji. Pamiętaj, że aplikacja może nie działać zgodnie z oczekiwaniami.",
    "Never" : "Nigdy",
    "An error occurred during the request. Unable to proceed." : "Wystąpił błąd podczas żądania. Nie można kontynuować.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikacja została włączona, ponieważ wymaga aktualizacji. Za 5 sekund nastąpi przekierowanie do strony aktualizacji.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Błąd: Ta aplikacja nie zostanie włączona ze względu na możliwość niestabilnej pracy serwera",
    "Administrator documentation" : "Dokumentacja administratora",
    "Documentation" : "Dokumentacja",
    "Forum" : "Forum",
    "Login" : "Login",
    "Plain" : "Czysty tekst",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Otwórz dokumentację",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Należy skonfigurować ten serwer, aby umożliwić wysyłanie wiadomości e-mail z powiadomieniami i resetowaniem hasła.",
    "Send mode" : "Sposób wysyłania",
    "Encryption" : "Szyfrowanie",
    "Sendmail mode" : "Tryb wysyłania poczty",
    "From address" : "Z adresu",
    "Authentication method" : "Metoda uwierzytelnienia",
    "Authentication required" : "Wymagane uwierzytelnienie",
    "Server address" : "Adres serwera",
    "Port" : "Port",
    "Credentials" : "Poświadczenia",
    "SMTP Username" : "Użytkownik SMTP",
    "SMTP Password" : "Hasło SMTP",
    "Save" : "Zapisz",
    "Test and verify email settings" : "Przetestuj i zweryfikuj ustawienia poczty e-mail",
    "Send email" : "Wyślij e-mail",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Poprawna konfiguracja jest ważna dla bezpieczeństwa i wydajności Twojej instancji. W celach pomocniczych przeprowadzane jest automatyczne sprawdzanie. Więcej informacji możesz znaleźć w dokumentacji.",
    "All checks passed." : "Wszystkie testy konfiguracji zakończyły się pomyślnie.",
    "There are some errors regarding your setup." : "Występują błędy dotyczące konfiguracji.",
    "There are some warnings regarding your setup." : "Znaleziono zastrzeżenia w Twojej konfiguracji.",
    "Checking for system and security issues." : "Sprawdzanie błędów systemu i bezpieczeństwa.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Sprawdź dokładnie <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">instrukcje instalacji ↗</a> oraz sprawdź, czy nie ma błędów lub ostrzeżeń w <a href=\"%2$s\">dzienniku</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Sprawdź bezpieczeństwo swojego serwera Nextcloud <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">naszym skanerem bezpieczeństwa ↗</a>.",
    "Version" : "Wersja",
    "You need to enable the File sharing App." : "Musisz włączyć aplikację do udostępniania plików.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Jako administrator możesz zoptymalizować ustawienia udostępniania. Szczegółowe informacje znajdziesz w dokumentacji.",
    "Allow apps to use the Share API" : "Zezwalaj aplikacjom na korzystanie z API udostępniania",
    "Set default expiration date for shares" : "Ustaw domyślną datę ważności udostępnień",
    "Expire after" : "Wygasa po",
    "day(s)" : "dzień(-ni)",
    "Enforce expiration date" : "Wymuszaj datę wygaśnięcia",
    "Set default expiration date for shares to other servers" : "Ustaw domyślną datę ważności udostępnień na innych serwerach",
    "Allow users to share via link and emails" : "Zezwalaj użytkownikom na udostępnianie za pośrednictwem linków i e-maili",
    "Allow public uploads" : "Zezwalaj na publiczne wysyłanie",
    "Always ask for a password" : "Zawsze pytaj o hasło",
    "Enforce password protection" : "Wymuszaj zabezpieczenie hasłem",
    "Exclude groups from password requirements:" : "Wyklucz grupy dla wymagań hasła:",
    "Set default expiration date" : "Ustaw domyślną datę wygaśnięcia",
    "Exclude groups from creating link shares:" : "Wyklucz grupy z tworzenia udostępnionych linków:",
    "Allow resharing" : "Zezwalaj na udostępnianie dalej",
    "Allow sharing with groups" : "Zezwalaj na udostępnianie grupom",
    "Restrict users to only share with users in their groups" : "Ogranicz użytkownikom możliwość udostępniania, pozwól tylko w swoich grupach",
    "Exclude groups from sharing" : "Wyklucz grupy z udostępniania",
    "These groups will still be able to receive shares, but not to initiate them." : "Grupy te nadal będą mogły otrzymywać udostępnienia, ale nie będą mogły ich tworzyć.",
    "Allow username autocompletion in share dialog" : "Zezwalaj na automatyczne uzupełnianie nazwy użytkownika w oknie udostępnienia",
    "Allow username autocompletion to users within the same groups" : "Zezwalaj na automatyczne uzupełnianie nazwy użytkownika dla użytkowników w tych samych grupach",
    "Allow username autocompletion to users based on phone number integration" : "Zezwalaj na automatyczne uzupełnianie nazw użytkowników na podstawie integracji numeru telefonu",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Jeśli automatyczne uzupełnianie \"ta sama grupa\" i \"integracja numeru telefonu\" są włączone, wystarczy dopasowanie w jednej z nich, aby pokazać użytkownikowi.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Zezwalaj na autouzupełnianie podczas wpisywania pełnej nazwy lub adresu e-mail (ignorując brak dopasowania książki telefonicznej i bycie w tej samej grupie)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Pokaż tekst zastrzeżenia na stronie przesyłania linków publicznych (wyświetlane tylko wtedy, gdy lista plików jest ukryta)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Ten tekst zostanie wyświetlony na stronie przesyłania linków publicznych, gdy lista plików jest ukryta.",
    "Default share permissions" : "Domyślne uprawnienia dla udostępnień",
    "Reasons to use Nextcloud in your organization" : "Dlaczego warto korzystać z Nextcloud w Twojej organizacji",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Opracowane przez {communityopen}społeczność Nextcloud{linkclose}, {githubopen}kod źródłowy{linkclose} jest objęty licencją {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Polub nas na Facebook'u",
    "Follow us on Twitter" : "Bądź z nami na Twitterze",
    "Follow us on Mastodon" : "Bądź z nami na Mastodonie",
    "Check out our blog" : "Sprawdź nasz blog",
    "Subscribe to our newsletter" : "Subskrybuj nasz newsletter",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "To wydanie społecznościowe Nextcloud nie jest obsługiwane i powiadomienia natychmiastowe są niedostępne.",
    "Use a second factor besides your password to increase security for your account." : "Użyj drugiego zabezpieczenia oprócz hasła, aby zwiększyć bezpieczeństwo konta.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Jeśli używasz aplikacji innych firm do łączenia się z Nextcloud, upewnij się, że utworzyłeś i skonfigurowałeś hasło aplikacji dla każdej przed włączeniem uwierzytelniania dwuskładnikowego.",
    "Migration in progress. Please wait until the migration is finished" : "Migracja w toku. Poczekaj na zakończenie migracji.",
    "Migration started …" : "Migracja rozpoczęta…",
    "An error occurred while changing your language. Please reload the page and try again." : "Wystąpił błąd podczas zmiany języka. Przeładuj stronę i spróbuj ponownie.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Wystąpił błąd podczas zmiany ustawień lokalnych. Przeładuj stronę i spróbuj ponownie.",
    "Select a profile picture" : "Wybierz zdjęcie profilowe",
    "Week starts on {fdow}" : "Tydzień zaczyna się w {fdow}",
    "Couldn't remove app." : "Nie można usunąć aplikacji.",
    "Couldn't update app." : "Nie można zaktualizować aplikacji.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "System zaplecza nie obsługuje zmiany hasła, ale klucz szyfrowania użytkownika został zaktualizowany.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Nie można określić, czy wersja TLS cURL jest aktualna, ponieważ wystąpił błąd podczas żądania HTTPS skierowanego do https://nextcloud.com. Aby uzyskać więcej informacji, sprawdź plik dziennika nextcloud.",
    "You need to set your user email before being able to send test emails." : "Musisz ustawić e-mail użytkownika, aby móc wysyłać e-maile testowe.",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Unieważnienie tego tokena uniemożliwi czyszczenie urządzenia, jeśli jeszcze nie zostało rozpoczęte.",
    "Set as primary mail" : "Ustaw jako podstawową pocztę",
    "Change privacy level of email" : "Zmień poziom prywatności adresu e-mail",
    "All languages" : "Wszystkie języki",
    "Everyone" : "Wszyscy",
    "An error occured during the request. Unable to proceed." : "Wystąpił błąd zapytania. Nie można kontynuować.",
    "Test email settings" : "Przetestuj ustawienia poczty e-mail",
    "Please read carefully before activating server-side encryption: " : "Przeczytaj uważnie przed aktywacją szyfrowania po stronie serwera:",
    "Enable encryption" : "Włącz szyfrowanie",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Musisz zmigrować swoje klucze szyfrujące ze starego szyfrowania (ownCloud <= 8.0) do nowego. Włącz \"Domyślny moduł szyfrowania\" i uruchom 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Musisz zmigrować swoje klucze szyfrujące ze starego szyfrowania (ownCloud <= 8.0) do nowego.",
    "Start migration" : "Rozpocznij migrację",
    "Last job execution ran %s. Something seems wrong." : "Ostatnie zadanie wykonano %s. Coś poszło nie tak.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Niektóre zadania nie były wykonywane od %s. Rozważ zwiększenie częstotliwości ich wykonywania.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Niektóre zadania nie były wykonywane od %s. Rozważ przejście na systemowy cron.",
    "Last job ran %s." : "Ostatnie zadanie wykonano %s.",
    "Background job didn’t run yet!" : "Zadanie w tle nie zostało wykonane ani razu!",
    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "Dla prawidłowego działania serwera, ważne jest, aby poprawnie skonfigurować zadania w tle. Zalecanym ustawieniem jest \"Cron\". Więcej informacji znajdziesz w dokumentacji.",
    "Pick background job setting" : "Wybierz ustawienie zadania w tle",
    "Recommended" : "Zalecane",
    "The cron.php needs to be executed by the system user \"%s\"." : "Cron.php musi zostać wykonywany przez użytkownika systemu \"%s\".",
    "days" : "dniach",
    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Zezwalaj na automatyczne uzupełnianie nazwy użytkownika podczas wpisywania imienia i nazwiska lub adresu e-mail (ignorowanie brakującego dopasowania w książce telefonicznej i przynależności do tej samej grupy)",
    "Change privacy level of profile picture" : "Zmień poziom prywatności zdjęcia profilowego",
    "Upload new" : "Wczytaj nowe",
    "Select from Files" : "Wybierz z Plików",
    "Remove image" : "Usuń zdjęcie",
    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Pamiętaj, że aktualizacja awatara może potrwać do 24 godzin.",
    "Choose as profile picture" : "Wybierz zdjęcie profilowe",
    "You are using <strong>%s</strong>" : "Używasz: <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Używasz: <strong>%1$s</strong> z <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Change privacy level of full name" : "Zmień poziom prywatności pełnej nazwy",
    "No display name set" : "Brak wyświetlanej nazwy",
    "Change privacy level of phone number" : "Zmień poziom prywatności numeru telefonu",
    "Address" : "Adres",
    "Change privacy level of address" : "Zmień poziom prywatności adresu",
    "Your postal address" : "Twój adres pocztowy",
    "Change privacy level of website" : "Zmień poziom prywatności strony internetowej",
    "It can take up to 24 hours before the account is displayed as verified." : "Do 24 godzin konto będzie widoczne jako zweryfikowane.",
    "Link https://…" : "Link https://…",
    "Change privacy level of Twitter profile" : "Zmień poziom prywatności profilu Twitter",
    "Twitter handle @…" : "Twitter @…",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Maksymalna liczba kluczy OPcache jest prawie przekroczona. Aby upewnić się, że wszystkie skrypty mogą być przechowywane w pamięci podręcznej, zaleca się zastosowanie <code>opcache.max_accelerated_files</code> w konfiguracji PHP z wartością wyższą niż <code>%s</code>.",
    "Admin privileges" : "Uprawnienia administratora",
    "Unable to update biography" : "Nie można zaktualizować biografii",
    "Unable to update full name" : "Nie można zaktualizować pełnej nazwy",
    "No full name set" : "Nie ustawiono pełnej nazwy",
    "Unable to update headline" : "Nie można zaktualizować nagłówka",
    "Unable to update organisation" : "Nie udało się zaktualizować organizacji",
    "Unable to update role" : "Nie można zaktualizować roli społecznej",
    "Change scope level of {accountProperty}" : "Zmień poziom zakresu {accountProperty}",
    "Unable to update federation scope of the primary {accountProperty}" : "Nie można zaktualizować zakresu federacji podstawowego {accountProperty}",
    "Unable to update federation scope of additional {accountProperty}" : "Nie można zaktualizować zakresu federacji dodatkowego {accountProperty}",
    "Avatar" : "Awatar"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
